.. currentmodule:: obspy.signal
.. automodule:: obspy.signal

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~array_analysis.array_processing
       ~array_analysis.array_rotation_strain
       ~trigger.ar_pick
       ~filter.bandpass
       ~filter.bandstop
       ~trigger.carl_sta_trig
       ~trigger.classic_sta_lta
       ~trigger.coincidence_trigger
       ~invsim.corn_freq_2_paz
       ~invsim.cosine_taper
       ~trigger.delayed_sta_lta
       ~filter.envelope
       ~interpolation.interpolate_1d
       ~interpolation.weighted_average_slopes
       ~invsim.estimate_magnitude
       ~invsim.evalresp
       ~filter.highpass
       ~filter.lowpass
       ~invsim.paz_to_freq_resp
       ~trigger.pk_baer
       ~polarization.polarization_analysis
       ~regression.linear_regression
       ~spectral_estimation.PPSD
       ~quality_control.MSEEDMetadata
       ~trigger.recursive_sta_lta
       ~rotate.rotate_ne_rt
       ~invsim.simulate_seismometer
       ~util.util_geo_km
       ~util.util_lon_lat
       ~cross_correlation.correlate
       ~trigger.z_detect

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       array_analysis
       calibration
       cpxtrace
       cross_correlation
       detrend
       differentiate_and_integrate
       filter
       freqattributes
       hoctavbands
       interpolation
       invsim
       konnoohmachismoothing
       polarization
       quality_control
       regression
       rotate
       spectral_estimation
       tf_misfit
       trigger
       util

    .. comment to end block
